@@ -4,8 +4,13 @@ from assertpy import assert_that
 from deepdriver.sdk.chart.chart import Chart, TYPE_CONFUSION_MATRIX
 
 
-def confusion_matrix(y_true, probs=None, preds=None, class_names=None, title=None) -> Chart:
+def confusion_matrix(y_true: list, probs: list = None, preds: list = None, class_names: list = None,
+                     title: str = None) -> Chart:
     assert_that(y_true).is_not_none()
+    if (probs is None) and (preds is None):
+        raise Exception("probs, preds one must have value")
+        return
+
     if (probs is not None) and (preds is None):
         preds = np.argmax(probs, axis=1).tolist()
 
