@@ -12,6 +12,7 @@ from optuna.exceptions import DuplicatedStudyError
 import deepdriver
 from deepdriver import logger
 from deepdriver import util
+from deepdriver.intergration.torch.torch import set_torch_log, TorchLog, get_torch_log
 from deepdriver.sdk.config import Config
 from deepdriver.sdk.data_types.experiment import set_experiment, Experiment, get_experiment
 from deepdriver.sdk.data_types.run import set_run, Run, get_run
@@ -43,6 +44,9 @@ def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Di
                 )
     set_run(run)
 
+    # init pytoch Log
+    set_torch_log(TorchLog())
+
     # init config
     deepdriver.config = Config()
     if config:
